@@ -72,6 +72,17 @@ class GoogleAnalytics {
         GoogleAnalyticsBridge.trackPurchaseEvent(getTrackerId(), product, transaction, eventCategory, eventAction);
     }
 
+    /**
+     * Track a purchase event. This uses the Enhanced Ecommerce GA feature.
+     * @param  {Array} products       An array with products
+     * @param  {Object} transaction   An object with transaction values
+     * @param  {String} eventCategory The event category, defaults to Ecommerce
+     * @param  {String} eventAction   The event action, defaults to Purchase
+     */
+    static trackMultiProductsPurchaseEvent(products = [], transaction = {}, eventCategory = "Ecommerce", eventAction = "Purchase") {
+        GoogleAnalyticsBridge.trackMultiProductsPurchaseEvent(getTrackerId(), products, transaction, eventCategory, eventAction);
+    }
+
     /**
      * Track an exception
      * @param  {String} error The description of the error
@@ -212,6 +223,17 @@ class GoogleTagManager {
     static doubleForKey(key){
         return GoogleTagManagerBridge.doubleForKey(key);
     }
+
+    /**
+     * push a datalayer event for Google Analytics through Google Tag Manager.
+     * @param {String} eventName
+     * @param {Object} dictionaly An Map<String, Object> containing key and value pairs.
+              it must have atleast one key "event" with event name
+     *         example: {event: "eventName", pageId: "/home"}
+     */
+    static pushDataLayerEvent(dictionaly = {}){
+        GoogleTagManagerBridge.pushDataLayerEvent(dictionaly);
+    }
 }
 
 GoogleAnalytics.GoogleTagManager = GoogleTagManager;
